==> dev.biuro-1.14.0.tar.gz: dev.biuro-1.14.0/wp-content/plugins/biuro-contacts/public/partials/biuro-contacts-public--employees.php <==
<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://www.biuro.lt
 * @since      1.0.0
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public/partials
 */

/**
 * @link https://codex.wordpress.org/Creating_Options_Pages
 * @link https://www.smashingmagazine.com/2016/04/three-approaches-to-adding-configurable-fields-to-your-plugin/
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) die;
?>

<form id="form" name="form-employees" action="<?php echo esc_url( admin_url('admin-post.php') ); ?>" method="post" enctype="multipart/form-data" class="c-form c-form--employees">
    <div id="action" class="c-form--action"></div>

    <?php if (isset($_SESSION['employees--s']) && $_SESSION['employees--s'] == 1) : ?>
        <div class="c-form--success">
            <?php _e('Thank You, we have successfully received data about you.', 'biuro-contacts'); ?>
            <br>
            <?php _e('You can add information about yourself by adding a city, message or CV', 'biuro-contacts'); ?>
        </div>
    <?php endif; ?>

    <?php
        if ( isset($_SESSION['employees--captcha-status']) && $_SESSION['employees--captcha-status'] == 'error' ):
    ?>
        <div class="c-form--validation-static c-form--validation-error">
            <?php _e('Sorry, something went wrong. Please try again', 'biuro-contacts'); ?>
        </div>

    <?php
            unset($_SESSION['employees--captcha-status']);
        endif;
     ?>

<?php

    if ( !isset($_SESSION['employees--step']) || !$_SESSION['employees--step'] ):
        include_once('biuro-contacts-public--employees--step-1.php');
    else:
        include_once('biuro-contacts-public--employees--step-2.php');
    endif;
 ?>
    <input type="hidden" name="action" value="employees_post">
    <?php wp_nonce_field('employees_post_nonce'); ?>

    <input type="hidden" id="g-recaptcha-response" name="captcha" data-action="employees/">
</form>

<?php if(isset($_SESSION['employees--s']) && $_SESSION['employees--s'] == 1) {
?>
<script>
window.dataLayer = window.dataLayer || [];
</script>
<?php
    if (isset($attr['page']) && $attr['page'] == 'landing-1'):
?>
<script>
window.dataLayer.push({ event: 'b2c_form_submit_success_validated', label: 'Landing page 1' });
</script>
<?php
    elseif (isset($attr['page']) && $attr['page'] == 'landing-2'):
?>
<script>
window.dataLayer.push({ event: 'b2c_form_submit_success_validated', label: 'Landing page 2' });
</script>
<?php
    elseif (isset($attr['page']) && $attr['page'] == 'landing-3'):
?>
<script>
window.dataLayer.push({ event: 'b2c_form_submit_success_validated', label: 'Landing page 3' });
</script>
<?php
    elseif (isset($attr['page']) && $attr['page'] == 'landing-4'):
?>
<script>
window.dataLayer.push({ event: 'b2c_form_submit_success_validated', label: 'Landing page 4' });
</script>
<?php
    else:
?>
<script>
window.dataLayer.push({ event: 'b2c_form_submit_success_validated', label: 'Contact page' });
</script>
<?php
    endif;
?>
<?php
    unset($_SESSION['employees--s']);
}
?>

<?php
    if(isset($_SESSION['employees--s']) && $_SESSION['employees--s'] == 2) {
?>

<div class="c-modal">
    <div class="c-modal--inner">
        <svg width="67px" height="67px">
            <use xlink:href="#ico--success"></use>
        </svg>
        <p><?php _e('Thank You! The information has been successfully supplemented.', 'biuro-contacts'); ?></p>
        <p><button  class="js-modal--close o-btn c-btn--main"><?php _e('OK', 'biuro-contacts'); ?></button></p>
    </div>
</div>
<script>
window.dataLayer = window.dataLayer || [];
</script>
<?php
    if (isset($attr['page']) && $attr['page'] == 'landing-1'):
?>
<script>
window.dataLayer.push({ event: 'b2c_form_update_success_validated', label: 'Landing page 1' });
</script>
<?php
    elseif (isset($attr['page']) && $attr['page'] == 'landing-2'):
?>
<script>
window.dataLayer.push({ event: 'b2c_form_update_success_validated', label: 'Landing page 2' });
</script>
<?php
    else:
?>
<script>
window.dataLayer.push({ event: 'b2c_form_update_success_validated', label: 'Contact page' });
</script>
<?php
    endif;
?>
<?php
        unset($_SESSION['employees--s']);
    }
?>

==> dev.biuro-1.20.1.tar.gz: dev.biuro-1.20.1/wp-content/plugins/biuro-contacts/public/partials/biuro-contacts-public--employees.php <==
<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://www.biuro.lt
 * @since      1.0.0
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public/partials
 */

/**
 * @link https://codex.wordpress.org/Creating_Options_Pages
 * @link https://www.smashingmagazine.com/2016/04/three-approaches-to-adding-configurable-fields-to-your-plugin/
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) die;
?>

<form id="form" name="form-employees" action="<?php echo esc_url( admin_url('admin-post.php') ); ?>" method="post" enctype="multipart/form-data" class="c-form c-form--employees">
    <div id="action" class="c-form--action"></div>

    <?php if (isset($_SESSION['employees--s']) && $_SESSION['employees--s'] == 1) : ?>
        <div class="c-form--success">
            <?php _e('Thank You, we have successfully received data about you.', 'biuro-contacts'); ?>
            <br>
            <?php _e('You can add information about yourself by adding a city, message or CV', 'biuro-contacts'); ?>
        </div>
    <?php endif; ?>

    <?php
        if ( isset($_SESSION['employees--captcha-status']) && $_SESSION['employees--captcha-status'] == 'error' ):
    ?>
        <div class="c-form--validation-static c-form--validation-error">
            <?php _e('Sorry, something went wrong. Please try again', 'biuro-contacts'); ?>
        </div>

    <?php
            unset($_SESSION['employees--captcha-status']);
        endif;
     ?>

<?php

    if ( !isset($_SESSION['employees--step']) || !$_SESSION['employees--step'] ):
        include_once('biuro-contacts-public--employees--step-1.php');
    else:
        include_once('biuro-contacts-public--employees--step-2.php');
    endif;
 ?>
    <input type="hidden" name="action" value="employees_post">
    <?php wp_nonce_field('employees_post_nonce'); ?>

    <input type="hidden" id="g-recaptcha-response" name="captcha" data-action="employees/">
</form>

<?php if(isset($_SESSION['employees--s']) && $_SESSION['employees--s'] == 1) {
?>
<script>
window.dataLayer = window.dataLayer || [];
</script>
<?php
    if (isset($attr['page']) && $attr['page'] == 'landing-1'):
?>
<script>
window.dataLayer.push({ event: 'b2c_form_submit_success_validated', label: 'Landing page 1' });
</script>
<?php
    elseif (isset($attr['page']) && $attr['page'] == 'landing-2'):
?>
<script>
window.dataLayer.push({ event: 'b2c_form_submit_success_validated', label: 'Landing page 2' });
</script>
<?php
    elseif (isset($attr['page']) && $attr['page'] == 'landing-3'):
?>
<script>
window.dataLayer.push({ event: 'b2c_form_submit_success_validated', label: 'Landing page 3' });
</script>
<?php
    elseif (isset($attr['page']) && $attr['page'] == 'landing-4'):
?>
<script>
window.dataLayer.push({ event: 'b2c_form_submit_success_validated', label: 'Landing page 4' });
</script>
<?php
    else:
?>
<script>
window.dataLayer.push({ event: 'b2c_form_submit_success_validated', label: 'Contact page' });
</script>
<?php
    endif;
?>
<?php
    unset($_SESSION['employees--s']);
}
?>

<?php
    if(isset($_SESSION['employees--s']) && $_SESSION['employees--s'] == 2) {
?>

<div class="c-modal">
    <div class="c-modal--inner">
        <svg width="67px" height="67px">
            <use href="#ico--success"></use>
        </svg>
        <p><?php _e('Thank You! The information has been successfully supplemented.', 'biuro-contacts'); ?></p>
        <p><button  class="js-modal--close o-btn c-btn--main"><?php _e('OK', 'biuro-contacts'); ?></button></p>
    </div>
</div>
<script>
window.dataLayer = window.dataLayer || [];
</script>
<?php
    if (isset($attr['page']) && $attr['page'] == 'landing-1'):
?>
<script>
window.dataLayer.push({ event: 'b2c_form_update_success_validated', label: 'Landing page 1' });
</script>
<?php
    elseif (isset($attr['page']) && $attr['page'] == 'landing-2'):
?>
<script>
window.dataLayer.push({ event: 'b2c_form_update_success_validated', label: 'Landing page 2' });
</script>
<?php
    else:
?>
<script>
window.dataLayer.push({ event: 'b2c_form_update_success_validated', label: 'Contact page' });
</script>
<?php
    endif;
?>
<?php
        unset($_SESSION['employees--s']);
    }
?>
